@@ -2580,11 +2580,6 @@ gtk_source_buffer_join_lines (GtkSourceBuffer *buffer,
 	g_return_if_fail (start != NULL);
 	g_return_if_fail (end != NULL);
 
-	if (gtk_text_iter_get_line (start) == gtk_text_iter_get_line (end))
-	{
-		return;
-	}
-
 	gtk_text_iter_order (start, end);
 
 	text_buffer = GTK_TEXT_BUFFER (buffer);
@@ -2593,6 +2588,10 @@ gtk_source_buffer_join_lines (GtkSourceBuffer *buffer,
 	gtk_text_buffer_begin_user_action (text_buffer);
 
 	move_to_line_text_end (start);
+	if (!gtk_text_iter_ends_line (end))
+	{
+		gtk_text_iter_forward_to_line_end (end);
+	}
 
 	while (gtk_text_iter_compare (start, end) < 0)
 	{
@@ -2608,12 +2607,16 @@ gtk_source_buffer_join_lines (GtkSourceBuffer *buffer,
 			{
 				break;
 			}
-		} while (gtk_text_iter_forward_char (&iter));
+		} while (gtk_text_iter_forward_char (&iter) &&
+			 gtk_text_iter_compare (&iter, end) < 0);
 
 		if (!gtk_text_iter_is_end (&iter))
 		{
 			gtk_text_buffer_delete (text_buffer, start, &iter);
-			gtk_text_buffer_insert (text_buffer, start, " ", 1);
+			if (!gtk_text_iter_ends_line (start))
+			{
+				gtk_text_buffer_insert (text_buffer, start, " ", 1);
+			}
 		}
 
 		move_to_line_text_end (start);
