@@ -23,16 +23,14 @@
 /**
  * SECTION:completionproposal
  * @title: GtkSourceCompletionProposal
- * @short_description: Completion proposal object
+ * @short_description: Completion proposal interface
  *
  * The proposal interface represents a completion item in the completion window.
  * It provides information on how to display the completion item and what action
  * should be taken when the completion item is activated.
  */
 
-#include <gtksourceview/gtksourcecompletionproposal.h>
-
-#include "gtksourceview-marshal.h"
+#include "gtksourcecompletionproposal.h"
 
 /* Signals */
 enum
@@ -78,7 +76,7 @@ gtk_source_completion_proposal_get_info_default (GtkSourceCompletionProposal *pr
 }
 
 static guint
-gtk_source_completion_proposal_hash_default	(GtkSourceCompletionProposal *proposal)
+gtk_source_completion_proposal_hash_default (GtkSourceCompletionProposal *proposal)
 {
 	return g_direct_hash (proposal);
 }
@@ -119,11 +117,8 @@ gtk_source_completion_proposal_default_init (GtkSourceCompletionProposalIface *i
 			      G_TYPE_FROM_INTERFACE (iface),
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 			      G_STRUCT_OFFSET (GtkSourceCompletionProposalIface, changed),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
+			      NULL, NULL, NULL,
+			      G_TYPE_NONE, 0);
 
 		initialized = TRUE;
 	}
@@ -135,7 +130,7 @@ gtk_source_completion_proposal_default_init (GtkSourceCompletionProposalIface *i
  *
  * Gets the label of @proposal. The label is shown in the list of proposals as
  * plain text. If you need any markup (such as bold or italic text), you have
- * to implement #gtk_source_completion_proposal_get_markup. The returned string
+ * to implement gtk_source_completion_proposal_get_markup(). The returned string
  * must be freed with g_free().
  *
  * Returns: a new string containing the label of @proposal.
@@ -154,7 +149,7 @@ gtk_source_completion_proposal_get_label (GtkSourceCompletionProposal *proposal)
  *
  * Gets the label of @proposal with markup. The label is shown in the list of
  * proposals and may contain markup. This will be used instead of
- * #gtk_source_completion_proposal_get_label if implemented. The returned string
+ * gtk_source_completion_proposal_get_label() if implemented. The returned string
  * must be freed with g_free().
  *
  * Returns: a new string containing the label of @proposal with markup.
@@ -174,7 +169,9 @@ gtk_source_completion_proposal_get_markup (GtkSourceCompletionProposal *proposal
  * Gets the text of @proposal. The text that is inserted into
  * the text buffer when the proposal is activated by the default activation.
  * You are free to implement a custom activation handler in the provider and
- * not implement this function. The returned string must be freed with g_free().
+ * not implement this function. For more information, see
+ * gtk_source_completion_provider_activate_proposal(). The returned string must
+ * be freed with g_free().
  *
  * Returns: a new string containing the text of @proposal.
  */
@@ -226,11 +223,11 @@ gtk_source_completion_proposal_get_info (GtkSourceCompletionProposal *proposal)
  * @proposal: a #GtkSourceCompletionProposal.
  *
  * Get the hash value of @proposal. This is used to (together with
- * #gtk_source_completion_proposal_equal) to match proposals in the completion
- * model. By default, it uses a direct hash (#g_direct_hash).
+ * gtk_source_completion_proposal_equal()) to match proposals in the completion
+ * model. By default, it uses a direct hash (g_direct_hash()).
  *
  * Returns: The hash value of @proposal.
- **/
+ */
 guint
 gtk_source_completion_proposal_hash (GtkSourceCompletionProposal *proposal)
 {
@@ -245,11 +242,11 @@ gtk_source_completion_proposal_hash (GtkSourceCompletionProposal *proposal)
  * @other: a #GtkSourceCompletionProposal.
  *
  * Get whether two proposal objects are the same.  This is used to (together
- * with #gtk_source_completion_proposal_hash) to match proposals in the
- * completion model. By default, it uses direct equality (#g_direct_equal).
+ * with gtk_source_completion_proposal_hash()) to match proposals in the
+ * completion model. By default, it uses direct equality (g_direct_equal()).
  *
  * Returns: %TRUE if @proposal and @object are the same proposal
- **/
+ */
 gboolean
 gtk_source_completion_proposal_equal (GtkSourceCompletionProposal *proposal,
                                       GtkSourceCompletionProposal *other)
